"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupRenderer = exports.RootRenderer = exports.SchemaGridItem = exports.SchemaGridHandler = exports.getGridClasses = void 0;

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _clsx = _interopRequireDefault(require("clsx"));

var getGridClasses = function getGridClasses(schema) {
  var classNameArray = [];
  var view = schema ? schema.getIn(['view']) : undefined;

  if (view && view.get('sizeXs')) {
    classNameArray.push('col-' + view.get('sizeXs'));
  } else {
    classNameArray.push('col-12');
  }

  if (view && view.get('sizeSm')) {
    classNameArray.push('col-sm-' + view.get('sizeSm'));
  }

  if (view && view.get('sizeMd')) {
    classNameArray.push('col-md-' + view.get('sizeMd'));
  }

  if (view && view.get('sizeLg')) {
    classNameArray.push('col-lg-' + view.get('sizeLg'));
  }

  if (view && view.get('sizeXl')) {
    classNameArray.push('col-xl-' + view.get('sizeXl'));
  }

  return classNameArray;
};

exports.getGridClasses = getGridClasses;

var SchemaGridItem = function SchemaGridItem(_ref) {
  var children = _ref.children,
      schema = _ref.schema;
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: getGridClasses(schema).join(' ')
  }, children);
};

exports.SchemaGridItem = SchemaGridItem;

var RootRenderer = function RootRenderer(props) {
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: 'row'
  }, props.children);
};

exports.RootRenderer = RootRenderer;

var GroupRenderer = function GroupRenderer(_ref2) {
  var children = _ref2.children;
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: (0, _clsx["default"])('row', 'px-0')
  }, children);
};

exports.GroupRenderer = GroupRenderer;

var SchemaGridHandler = function SchemaGridHandler(props) {
  var schema = props.schema,
      noGrid = props.noGrid,
      isVirtual = props.isVirtual;

  if (noGrid || isVirtual || schema.getIn(['view', 'noGrid'])) {
    return /*#__PURE__*/_react["default"].createElement(_uiSchema.NextPluginRenderer, props);
  }

  return /*#__PURE__*/_react["default"].createElement(SchemaGridItem, {
    schema: schema
  }, /*#__PURE__*/_react["default"].createElement(_uiSchema.NextPluginRenderer, props));
};

exports.SchemaGridHandler = SchemaGridHandler;