"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OptionsCheck = void 0;

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _immutable = require("immutable");

var _reactUid = require("react-uid");

var _LocaleHelperText = require("../../Component/LocaleHelperText/LocaleHelperText");

var CheckInput = function CheckInput(_ref) {
  var currentValue = _ref.currentValue,
      onChange = _ref.onChange,
      label = _ref.label,
      value = _ref.value,
      classForm = _ref.classForm,
      classLabel = _ref.classLabel,
      classFormControl = _ref.classFormControl;
  var uid = (0, _reactUid.useUID)();
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: classForm
  }, /*#__PURE__*/_react["default"].createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: currentValue,
    onChange: onChange
  }), /*#__PURE__*/_react["default"].createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

var checkActive = function checkActive(list, name) {
  return list && list.contains && typeof list.contains(name) !== 'undefined' ? list.contains(name) : false;
};

var OptionsCheckValue = (0, _uiSchema.extractValue)((0, _uiSchema.memo)(function (_ref2) {
  var enumVal = _ref2.enumVal,
      storeKeys = _ref2.storeKeys,
      value = _ref2.value,
      _onChange = _ref2.onChange,
      classLabel = _ref2.classLabel,
      classFormControl = _ref2.classFormControl,
      classForm = _ref2.classForm,
      schema = _ref2.schema,
      required = _ref2.required;
  return enumVal ? enumVal.map(function (enum_name) {
    var isActive = checkActive(value, enum_name);
    return /*#__PURE__*/_react["default"].createElement(CheckInput, {
      key: enum_name,
      value: enum_name,
      classForm: classForm,
      classLabel: classLabel,
      classFormControl: classFormControl,
      currentValue: isActive,
      onChange: function onChange() {
        _onChange(storeKeys, ['value'], {
          type: 'update',
          update: function update(_ref3) {
            var _ref3$value = _ref3.value,
                val = _ref3$value === void 0 ? (0, _immutable.List)() : _ref3$value;
            return {
              value: (0, _uiSchema.sortScalarList)(checkActive(val, enum_name) ? val["delete"](val.indexOf(enum_name)) : val.push(enum_name))
            };
          },
          schema: schema,
          required: required
        });
      },
      label: /*#__PURE__*/_react["default"].createElement(_uiSchema.Trans, {
        schema: schema.get('t'),
        text: storeKeys.insert(0, 'widget').concat((0, _immutable.List)(['enum', enum_name])).join('.'),
        context: (0, _immutable.Map)({
          'relative': (0, _immutable.List)(['enum', enum_name])
        }),
        fallback: (0, _uiSchema.beautifyKey)(enum_name, schema.get('ttEnum'))
      })
    });
  }).valueSeq() : null;
}));

var OptionsCheck = function OptionsCheck(_ref4) {
  var schema = _ref4.schema,
      storeKeys = _ref4.storeKeys,
      showValidity = _ref4.showValidity,
      errors = _ref4.errors,
      ownKey = _ref4.ownKey,
      required = _ref4.required;
  var enumVal = schema.get('enum');
  if (!enumVal) return null;
  var classForm = ['custom-control', 'custom-checkbox'];
  var classLabel = ['custom-control-label', 'text-light'];
  var classFormControl = ['custom-control-input', 'checkbox-inline'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_uiSchema.TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/_react["default"].createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    enumVal: enumVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/_react["default"].createElement(_LocaleHelperText.ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

exports.OptionsCheck = OptionsCheck;