import React from "react";
import { NextPluginRenderer } from "@ui-schema/ui-schema";
import clsx from "clsx";
export const getGridClasses = schema => {
  let classNameArray = [];
  const view = schema ? schema.getIn(['view']) : undefined;

  if (view && view.get('sizeXs')) {
    classNameArray.push('col-' + view.get('sizeXs'));
  } else {
    classNameArray.push('col-12');
  }

  if (view && view.get('sizeSm')) {
    classNameArray.push('col-sm-' + view.get('sizeSm'));
  }

  if (view && view.get('sizeMd')) {
    classNameArray.push('col-md-' + view.get('sizeMd'));
  }

  if (view && view.get('sizeLg')) {
    classNameArray.push('col-lg-' + view.get('sizeLg'));
  }

  if (view && view.get('sizeXl')) {
    classNameArray.push('col-xl-' + view.get('sizeXl'));
  }

  return classNameArray;
};

const SchemaGridItem = ({
  children,
  schema
}) => {
  return /*#__PURE__*/React.createElement("div", {
    className: getGridClasses(schema).join(' ')
  }, children);
};

const RootRenderer = props => /*#__PURE__*/React.createElement("div", {
  className: 'row'
}, props.children);

const GroupRenderer = ({
  children
}) => /*#__PURE__*/React.createElement("div", {
  className: clsx('row', 'px-0')
}, children);

const SchemaGridHandler = props => {
  const {
    schema,
    noGrid,
    isVirtual
  } = props;

  if (noGrid || isVirtual || schema.getIn(['view', 'noGrid'])) {
    return /*#__PURE__*/React.createElement(NextPluginRenderer, props);
  }

  return /*#__PURE__*/React.createElement(SchemaGridItem, {
    schema: schema
  }, /*#__PURE__*/React.createElement(NextPluginRenderer, props));
};

export { SchemaGridHandler, SchemaGridItem, RootRenderer, GroupRenderer };