import React from 'react';
import { TransTitle, Trans, beautifyKey, extractValue, memo, sortScalarList } from '@ui-schema/ui-schema';
import { List, Map } from 'immutable';
import { useUID } from 'react-uid';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';

const CheckInput = ({
  currentValue,
  onChange,
  label,
  value,
  classForm,
  classLabel,
  classFormControl
}) => {
  const uid = useUID();
  return /*#__PURE__*/React.createElement("div", {
    className: classForm
  }, /*#__PURE__*/React.createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: currentValue,
    onChange: onChange
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

const checkActive = (list, name) => list && list.contains && typeof list.contains(name) !== 'undefined' ? list.contains(name) : false;

const OptionsCheckValue = extractValue(memo(({
  enumVal,
  storeKeys,
  value,
  onChange,
  classLabel,
  classFormControl,
  classForm,
  schema,
  required
}) => enumVal ? enumVal.map(enum_name => {
  const isActive = checkActive(value, enum_name);
  return /*#__PURE__*/React.createElement(CheckInput, {
    key: enum_name,
    value: enum_name,
    classForm: classForm,
    classLabel: classLabel,
    classFormControl: classFormControl,
    currentValue: isActive,
    onChange: () => {
      onChange(storeKeys, ['value'], {
        type: 'update',
        update: ({
          value: val = List()
        }) => ({
          value: sortScalarList(checkActive(val, enum_name) ? val.delete(val.indexOf(enum_name)) : val.push(enum_name))
        }),
        schema,
        required
      });
    },
    label: /*#__PURE__*/React.createElement(Trans, {
      schema: schema.get('t'),
      text: storeKeys.insert(0, 'widget').concat(List(['enum', enum_name])).join('.'),
      context: Map({
        'relative': List(['enum', enum_name])
      }),
      fallback: beautifyKey(enum_name, schema.get('ttEnum'))
    })
  });
}).valueSeq() : null));

const OptionsCheck = ({
  schema,
  storeKeys,
  showValidity,
  errors,
  ownKey,
  required
}) => {
  const enumVal = schema.get('enum');
  if (!enumVal) return null;
  let classForm = ['custom-control', 'custom-checkbox'];
  let classLabel = ['custom-control-label', 'text-light'];
  let classFormControl = ['custom-control-input', 'checkbox-inline'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/React.createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    enumVal: enumVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { OptionsCheck };